@@ -1,5 +1,7 @@
-#![doc(html_root_url = "https://docs.rs/tokio-threadpool/0.1.10")]
+#![doc(html_root_url = "https://docs.rs/tokio-threadpool/0.1.15")]
 #![deny(warnings, missing_docs, missing_debug_implementations)]
+// Our MSRV doesn't allow us to fix these warnings yet
+#![allow(rust_2018_idioms)]
 
 //! A work-stealing based thread pool for executing futures.
 //!
@@ -9,7 +11,7 @@
 //! I/O. Usually, users will not create a `ThreadPool` instance directly, but
 //! will use one via a [`runtime`].
 //!
-//! The `TheadPool` structure manages two sets of threads:
+//! The `ThreadPool` structure manages two sets of threads:
 //!
 //! * Worker threads.
 //! * Backup threads.
@@ -79,13 +81,14 @@
 
 extern crate tokio_executor;
 
-extern crate crossbeam_channel;
-extern crate crossbeam_deque as deque;
+extern crate crossbeam_deque;
+extern crate crossbeam_queue;
 extern crate crossbeam_utils;
 #[macro_use]
 extern crate futures;
 extern crate num_cpus;
 extern crate rand;
+extern crate slab;
 
 #[macro_use]
 extern crate log;
@@ -158,5 +161,5 @@ pub use blocking::{blocking, BlockingError};
 pub use builder::Builder;
 pub use sender::Sender;
 pub use shutdown::Shutdown;
-pub use thread_pool::{ThreadPool, SpawnHandle};
+pub use thread_pool::{SpawnHandle, ThreadPool};
 pub use worker::{Worker, WorkerId};
